@@ -4,7 +4,6 @@ use crate::error::ToPyResult;
 use pyo3::exceptions;
 use pyo3::prelude::*;
 use pyo3::types::*;
-use pyo3::{PyMappingProtocol, PyObjectProtocol};
 use tk::normalizer::{char_to_bytes, NormalizedString, Range, SplitDelimiterBehavior};
 use tk::pattern::Pattern;
 
@@ -192,7 +191,7 @@ fn slice(
 /// Args:
 ///     sequence: str:
 ///         The string sequence used to initialize this NormalizedString
-#[pyclass(module = "tokenizers", name=NormalizedString)]
+#[pyclass(module = "tokenizers", name = "NormalizedString")]
 #[derive(Clone)]
 pub struct PyNormalizedString {
     pub(crate) normalized: NormalizedString,
@@ -217,91 +216,91 @@ impl PyNormalizedString {
     }
 
     /// Runs the NFD normalization
-    #[text_signature = "(self)"]
+    #[pyo3(text_signature = "(self)")]
     fn nfd(&mut self) {
         self.normalized.nfd();
     }
 
     /// Runs the NFKD normalization
-    #[text_signature = "(self)"]
+    #[pyo3(text_signature = "(self)")]
     fn nfkd(&mut self) {
         self.normalized.nfkd();
     }
 
     /// Runs the NFC normalization
-    #[text_signature = "(self)"]
+    #[pyo3(text_signature = "(self)")]
     fn nfc(&mut self) {
         self.normalized.nfc();
     }
 
     /// Runs the NFKC normalization
-    #[text_signature = "(self)"]
+    #[pyo3(text_signature = "(self)")]
     fn nfkc(&mut self) {
         self.normalized.nfkc();
     }
 
     /// Lowercase the string
-    #[text_signature = "(self)"]
+    #[pyo3(text_signature = "(self)")]
     fn lowercase(&mut self) {
         self.normalized.lowercase();
     }
 
     /// Uppercase the string
-    #[text_signature = "(self)"]
+    #[pyo3(text_signature = "(self)")]
     fn uppercase(&mut self) {
         self.normalized.uppercase();
     }
 
     /// Prepend the given sequence to the string
-    #[text_signature = "(self, s)"]
+    #[pyo3(text_signature = "(self, s)")]
     fn prepend(&mut self, s: &str) {
         self.normalized.prepend(s);
     }
 
     /// Append the given sequence to the string
-    #[text_signature = "(self, s)"]
+    #[pyo3(text_signature = "(self, s)")]
     fn append(&mut self, s: &str) {
         self.normalized.append(s);
     }
 
     /// Strip the left of the string
-    #[text_signature = "(self)"]
+    #[pyo3(text_signature = "(self)")]
     fn lstrip(&mut self) {
         self.normalized.lstrip();
     }
 
     /// Strip the right of the string
-    #[text_signature = "(self)"]
+    #[pyo3(text_signature = "(self)")]
     fn rstrip(&mut self) {
         self.normalized.rstrip();
     }
 
     /// Strip both ends of the string
-    #[text_signature = "(self)"]
+    #[pyo3(text_signature = "(self)")]
     fn strip(&mut self) {
         self.normalized.strip();
     }
 
     /// Clears the string
-    #[text_signature = "(self)"]
+    #[pyo3(text_signature = "(self)")]
     fn clear(&mut self) {
         self.normalized.clear();
     }
 
     /// Slice the string using the given range
-    #[text_signature = "(self, range)"]
+    #[pyo3(text_signature = "(self, range)")]
     fn slice(&self, range: PyRange) -> PyResult<Option<PyNormalizedString>> {
         slice(&self.normalized, &range)
     }
 
     /// Filter each character of the string using the given func
-    #[text_signature = "(self, func)"]
+    #[pyo3(text_signature = "(self, func)")]
     fn filter(&mut self, func: &PyAny) -> PyResult<()> {
         filter(&mut self.normalized, func)
     }
 
     /// Calls the given function for each character of the string
-    #[text_signature = "(self, func)"]
+    #[pyo3(text_signature = "(self, func)")]
     fn for_each(&self, func: &PyAny) -> PyResult<()> {
         for_each(&self.normalized, func)
     }
@@ -310,7 +309,7 @@ impl PyNormalizedString {
     ///
     /// Replaces each character of the string using the returned value. Each
     /// returned value **must** be a str of length 1 (ie a character).
-    #[text_signature = "(self, func)"]
+    #[pyo3(text_signature = "(self, func)")]
     fn map(&mut self, func: &PyAny) -> PyResult<()> {
         map(&mut self.normalized, func)
     }
@@ -328,7 +327,7 @@ impl PyNormalizedString {
     ///
     /// Returns:
     ///     A list of NormalizedString, representing each split
-    #[text_signature = "(self, pattern, behavior)"]
+    #[pyo3(text_signature = "(self, pattern, behavior)")]
     fn split(
         &mut self,
         pattern: PyPattern,
@@ -349,14 +348,11 @@ impl PyNormalizedString {
     ///
     ///     content: str:
     ///         The content to be used as replacement
-    #[text_signature = "(self, pattern, content)"]
+    #[pyo3(text_signature = "(self, pattern, content)")]
     fn replace(&mut self, pattern: PyPattern, content: &str) -> PyResult<()> {
         ToPyResult(self.normalized.replace(pattern, content)).into()
     }
-}
 
-#[pyproto]
-impl PyObjectProtocol<'p> for PyNormalizedString {
     fn __repr__(&self) -> String {
         format!(
             r#"NormalizedString(original="{}", normalized="{}")"#,
@@ -365,14 +361,11 @@ impl PyObjectProtocol<'p> for PyNormalizedString {
         )
     }
 
-    fn __str__(&'p self) -> &'p str {
+    fn __str__(&self) -> &str {
         self.normalized.get()
     }
-}
 
-#[pyproto]
-impl PyMappingProtocol<'p> for PyNormalizedString {
-    fn __getitem__(&self, range: PyRange<'p>) -> PyResult<Option<PyNormalizedString>> {
+    fn __getitem__(&self, range: PyRange<'_>) -> PyResult<Option<PyNormalizedString>> {
         slice(&self.normalized, &range)
     }
 }
@@ -389,7 +382,7 @@ impl From<PyNormalizedString> for NormalizedString {
     }
 }
 
-#[pyclass(module = "tokenizers", name=NormalizedStringRefMut)]
+#[pyclass(module = "tokenizers", name = "NormalizedStringRefMut")]
 #[derive(Clone)]
 pub struct PyNormalizedStringRefMut {
     inner: RefMutContainer<NormalizedString>,
