@@ -3,8 +3,8 @@ use pyo3::exceptions;
 use pyo3::prelude::*;
 
 /// Instantiate a new Regex with the given pattern
-#[pyclass(module = "tokenizers", name=Regex)]
-#[text_signature = "(self, pattern)"]
+#[pyclass(module = "tokenizers", name = "Regex")]
+#[pyo3(text_signature = "(self, pattern)")]
 pub struct PyRegex {
     pub inner: Regex,
     pub pattern: String,
