@@ -65,31 +65,16 @@ impl std::fmt::Debug for Unigram {
 
 static K_UNK_PENALTY: f64 = 10.0;
 
-#[derive(Debug)]
+#[derive(thiserror::Error, Debug)]
 pub enum UnigramError {
+    #[error("The vocabulary is empty but at least <unk> is needed")]
     EmptyVocabulary,
+    #[error("The `unk_id` is larger than vocabulary size")]
     UnkIdNotInVocabulary,
+    #[error("Encountered an unknown token but `unk_id` is missing")]
     MissingUnkId,
 }
 
-impl std::fmt::Display for UnigramError {
-    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
-        match self {
-            UnigramError::EmptyVocabulary => {
-                write!(f, "The vocabulary is empty but at least <unk> is needed")
-            }
-            UnigramError::UnkIdNotInVocabulary => {
-                write!(f, "The `unk_id` is larger than vocabulary size")
-            }
-            UnigramError::MissingUnkId => {
-                write!(f, "Encountered an unknown token but `unk_id` is missing")
-            }
-        }
-    }
-}
-
-impl std::error::Error for UnigramError {}
-
 impl Default for Unigram {
     fn default() -> Self {
         let vocab = vec![("<unk>".to_string(), 0.0)];
@@ -134,7 +119,7 @@ impl Unigram {
         let fuse_unk = true;
         let is_optimized = true;
 
-        Ok(Unigram {
+        Ok(Self {
             vocab,
             token_to_ids,
             trie,
