@@ -1,6 +1,7 @@
 use super::WordPiece;
 use crate::models::bpe::{BpeTrainer, BpeTrainerBuilder, BPE};
 use crate::tokenizer::{AddedToken, Result, Trainer};
+use serde::{Deserialize, Serialize};
 use std::collections::HashSet;
 
 /// A `WordPieceTrainerBuilder` can be used to create a `WordPieceTrainer` with a custom
@@ -87,7 +88,7 @@ impl WordPieceTrainerBuilder {
 }
 
 /// Trains a `WordPiece` model.
-#[derive(Default)]
+#[derive(Default, Deserialize, Serialize)]
 pub struct WordPieceTrainer {
     bpe_trainer: BpeTrainer,
 }
